Index — version 1.0.0

Hydrogen in Short-Term Electricity Markets

“Simplicity and Transparency in Power Systems Operation”

HysTEM is a multi-stage stochastic optimization model for the optimal operation scheduling of a Hydrogen-based Virtual Power Plant (H-VPP), which contains hydrogen-based energy storage systems (ESS), renewable energy sources (RES), and battery energy storage systems (BESS).

The model has been developed at the Instituto de Investigación Tecnológica (IIT) of the Universidad Pontificia Comillas.

# Index

- Introduction
- Input Data
  - Electric System Input Data
  - Hydrogen System Input Data
- Research projects